@@ -1,5 +1,7 @@
 <?php
 
+declare(strict_types=1);
+
 namespace Shaarli\NetscapeBookmarkParser;
 
 /**
@@ -12,12 +14,13 @@ class LoggerTestsUtils
     /**
      * Retrieve the
      *
-     * @param string $directory
-     * @return bool
+     * @param string|null $directory
+     *
+     * @return string|null
      */
-    public static function getLogFile($directory = 'logs')
+    public static function getLogFile(?string $directory = 'logs'): ?string
     {
         $logs = glob($directory . '/import*.log');
-        return ! empty ($logs) ? $logs[0] : false;
+        return ! empty($logs) ? $logs[0] : null;
     }
 }
