@@ -1,5 +1,7 @@
 <?php
 
+declare(strict_types=1);
+
 namespace Shaarli\NetscapeBookmarkParser;
 
 /**
@@ -7,12 +9,12 @@ namespace Shaarli\NetscapeBookmarkParser;
  *
  * The reference data has been dumped with Mozilla Firefox 46.0.1
  */
-class ParseFirefoxBookmarksTest extends \PHPUnit_Framework_TestCase
+class ParseFirefoxBookmarksTest extends TestCase
 {
     /**
      * Delete log file.
      */
-    public function tearDown()
+    protected function tearDown(): void
     {
         @unlink(LoggerTestsUtils::getLogFile());
     }
@@ -28,7 +30,7 @@ class ParseFirefoxBookmarksTest extends \PHPUnit_Framework_TestCase
 
         $this->assertEquals('', $bkm[0]['note']);
         $this->assertEquals('1', $bkm[0]['pub']);
-        $this->assertEquals('', $bkm[0]['tags']);
+        $this->assertEquals([], $bkm[0]['tags']);
         $this->assertEquals(
             '1460294956',
             $bkm[0]['time']
@@ -39,13 +41,13 @@ class ParseFirefoxBookmarksTest extends \PHPUnit_Framework_TestCase
         );
         $this->assertEquals(
             'place:folder=BOOKMARKS_MENU&folder=UNFILED_BOOKMARKS&folder=TOOLBAR'
-           .'&queryType=1&sort=12&maxResults=10&excludeQueries=1',
+            . '&queryType=1&sort=12&maxResults=10&excludeQueries=1',
             $bkm[0]['uri']
         );
 
         $this->assertEquals('', $bkm[0]['note']);
         $this->assertEquals('1', $bkm[0]['pub']);
-        $this->assertEquals('', $bkm[0]['tags']);
+        $this->assertEquals([], $bkm[0]['tags']);
         $this->assertEquals(
             '1460294956',
             $bkm[1]['time']
@@ -61,7 +63,7 @@ class ParseFirefoxBookmarksTest extends \PHPUnit_Framework_TestCase
 
         $this->assertEquals(
             'netscape-bookmark-parser - a php script (function) to parse netscape'
-           .' format bookmark files',
+            . ' format bookmark files',
             $bkm[2]['note']
         );
         $this->assertEquals(
@@ -69,7 +71,7 @@ class ParseFirefoxBookmarksTest extends \PHPUnit_Framework_TestCase
             $bkm[2]['pub']
         );
         $this->assertEquals(
-            'github php netscape parser',
+            ['github', 'php', 'netscape', 'parser'],
             $bkm[2]['tags']
         );
         $this->assertEquals(
@@ -78,7 +80,7 @@ class ParseFirefoxBookmarksTest extends \PHPUnit_Framework_TestCase
         );
         $this->assertEquals(
             'kafene/netscape-bookmark-parser: a php script (function) to parse'
-           .' netscape format bookmark files',
+            . ' netscape format bookmark files',
             $bkm[2]['title']
         );
         $this->assertEquals(
@@ -89,7 +91,7 @@ class ParseFirefoxBookmarksTest extends \PHPUnit_Framework_TestCase
         $this->assertEquals('', $bkm[3]['note']);
         $this->assertEquals('1', $bkm[3]['pub']);
         $this->assertEquals(
-            'lua script cpp dev',
+            ['lua', 'script', 'cpp', 'dev'],
             $bkm[3]['tags']
         );
         $this->assertEquals(
@@ -108,7 +110,7 @@ class ParseFirefoxBookmarksTest extends \PHPUnit_Framework_TestCase
         $this->assertEquals('', $bkm[4]['note']);
         $this->assertEquals('1', $bkm[4]['pub']);
         $this->assertEquals(
-            'php security best-practices dev web',
+            ['php', 'security', 'best-practices', 'dev', 'web'],
             $bkm[4]['tags']
         );
         $this->assertEquals(
@@ -117,7 +119,7 @@ class ParseFirefoxBookmarksTest extends \PHPUnit_Framework_TestCase
         );
         $this->assertEquals(
             'Survive The Deep End: PHP Security — Survive The Deep End:'
-           .' PHP Security :: v1.0a1',
+            . ' PHP Security :: v1.0a1',
             $bkm[4]['title']
         );
         $this->assertEquals(
@@ -134,7 +136,7 @@ class ParseFirefoxBookmarksTest extends \PHPUnit_Framework_TestCase
             $bkm[5]['pub']
         );
         $this->assertEquals(
-            'webcomic commit code review dev',
+            ['webcomic', 'commit', 'code', 'review', 'dev'],
             $bkm[5]['tags']
         );
         $this->assertEquals(
@@ -152,8 +154,8 @@ class ParseFirefoxBookmarksTest extends \PHPUnit_Framework_TestCase
 
         $this->assertEquals(
             'If running a Meetup feels like a full-time job, you&#39;re probably'
-           .' doing it wrong. Volunteering is important and you can make it work'
-           .' with some smart maneuvering.',
+            . ' doing it wrong. Volunteering is important and you can make it work'
+            . ' with some smart maneuvering.',
             $bkm[6]['note']
         );
         $this->assertEquals(
@@ -161,7 +163,7 @@ class ParseFirefoxBookmarksTest extends \PHPUnit_Framework_TestCase
             $bkm[6]['pub']
         );
         $this->assertEquals(
-            'meetup presentation event community',
+            ['meetup', 'presentation', 'event', 'community'],
             $bkm[6]['tags']
         );
         $this->assertEquals(
@@ -179,7 +181,7 @@ class ParseFirefoxBookmarksTest extends \PHPUnit_Framework_TestCase
 
         $this->assertEquals(
             'Let’s play a game. I’ll show you a picture and a couple videos'
-           .'—just watch the first five seconds or so—and you figure out&amp;#8230;',
+            . '—just watch the first five seconds or so—and you figure out&amp;#8230;',
             $bkm[7]['note']
         );
         $this->assertEquals(
@@ -187,7 +189,7 @@ class ParseFirefoxBookmarksTest extends \PHPUnit_Framework_TestCase
             $bkm[7]['pub']
         );
         $this->assertEquals(
-            'teapot 418 computer graphics image sythesis',
+            ['teapot', '418', 'computer', 'graphics', 'image', 'sythesis'],
             $bkm[7]['tags']
         );
         $this->assertEquals(
@@ -196,12 +198,12 @@ class ParseFirefoxBookmarksTest extends \PHPUnit_Framework_TestCase
         );
         $this->assertEquals(
             'The Most Important Object In Computer Graphics History Is This Teapot'
-           .' - Facts So Romantic - Nautilus',
+            . ' - Facts So Romantic - Nautilus',
             $bkm[7]['title']
         );
         $this->assertEquals(
             'http://nautil.us/blog/the-most-important-object-in-computer-graphics'
-           .'-history-is-this-teapot',
+            . '-history-is-this-teapot',
             $bkm[7]['uri']
         );
 
@@ -214,7 +216,7 @@ class ParseFirefoxBookmarksTest extends \PHPUnit_Framework_TestCase
             $bkm[8]['pub']
         );
         $this->assertEquals(
-            'github windows compose character keyboard input',
+            ['github', 'windows', 'compose', 'character', 'keyboard', 'input'],
             $bkm[8]['tags']
         );
         $this->assertEquals(
@@ -239,7 +241,7 @@ class ParseFirefoxBookmarksTest extends \PHPUnit_Framework_TestCase
             $bkm[9]['pub']
         );
         $this->assertEquals(
-            'hg mercurial version control scm python tutorial',
+            ['hg', 'mercurial', 'version', 'control', 'scm', 'python', 'tutorial'],
             $bkm[9]['tags']
         );
         $this->assertEquals(
@@ -264,7 +266,7 @@ class ParseFirefoxBookmarksTest extends \PHPUnit_Framework_TestCase
             $bkm[10]['pub']
         );
         $this->assertEquals(
-            'emacs editor django pony python mode',
+            ['emacs', 'editor', 'django', 'pony', 'python', 'mode'],
             $bkm[10]['tags']
         );
         $this->assertEquals(
@@ -277,7 +279,7 @@ class ParseFirefoxBookmarksTest extends \PHPUnit_Framework_TestCase
         );
         $this->assertEquals(
             'http://blog.deadpansincerity.com/2011/05/announcing-pony-mode-a-django'
-            .'-editing-mode-for-emacs/',
+            . '-editing-mode-for-emacs/',
             $bkm[10]['uri']
         );
 
@@ -290,7 +292,7 @@ class ParseFirefoxBookmarksTest extends \PHPUnit_Framework_TestCase
             $bkm[11]['pub']
         );
         $this->assertEquals(
-            'sysadmin test unix linux network security',
+            ['sysadmin', 'test', 'unix', 'linux', 'network', 'security'],
             $bkm[11]['tags']
         );
         $this->assertEquals(
@@ -315,7 +317,7 @@ class ParseFirefoxBookmarksTest extends \PHPUnit_Framework_TestCase
             $bkm[12]['pub']
         );
         $this->assertEquals(
-            'tolkien lord rings elves timeline graphics genealogy fantasy',
+            ['tolkien', 'lord', 'rings', 'elves', 'timeline', 'graphics', 'genealogy', 'fantasy'],
             $bkm[12]['tags']
         );
         $this->assertEquals(
@@ -340,7 +342,7 @@ class ParseFirefoxBookmarksTest extends \PHPUnit_Framework_TestCase
             $bkm[13]['pub']
         );
         $this->assertEquals(
-            'xkcd webcomic slope respect',
+            ['xkcd', 'webcomic', 'slope', 'respect'],
             $bkm[13]['tags']
         );
         $this->assertEquals(
@@ -365,7 +367,7 @@ class ParseFirefoxBookmarksTest extends \PHPUnit_Framework_TestCase
             $bkm[14]['pub']
         );
         $this->assertEquals(
-            'minecraft game indie pig wtf',
+            ['minecraft', 'game', 'indie', 'pig', 'wtf'],
             $bkm[14]['tags']
         );
         $this->assertEquals(
@@ -378,7 +380,7 @@ class ParseFirefoxBookmarksTest extends \PHPUnit_Framework_TestCase
         );
         $this->assertEquals(
             'http://gaming.stackexchange.com/questions/21261/is-it-dangerous-to-go-extreme'
-           .'-pig-riding-in-a-thunderstorm',
+            . '-pig-riding-in-a-thunderstorm',
             $bkm[14]['uri']
         );
 
@@ -391,7 +393,7 @@ class ParseFirefoxBookmarksTest extends \PHPUnit_Framework_TestCase
             $bkm[15]['pub']
         );
         $this->assertEquals(
-            'question faq bug report dev support',
+            ['question', 'faq', 'bug', 'report', 'dev', 'support'],
             $bkm[15]['tags']
         );
         $this->assertEquals(
@@ -416,7 +418,7 @@ class ParseFirefoxBookmarksTest extends \PHPUnit_Framework_TestCase
             $bkm[16]['pub']
         );
         $this->assertEquals(
-            'dev wikiwikiweb deadline rush',
+            ['dev', 'wikiwikiweb', 'deadline', 'rush'],
             $bkm[16]['tags']
         );
         $this->assertEquals(
@@ -441,7 +443,7 @@ class ParseFirefoxBookmarksTest extends \PHPUnit_Framework_TestCase
             $bkm[17]['pub']
         );
         $this->assertEquals(
-            'chocolate research wtf statistics nobel',
+            ['chocolate', 'research', 'wtf', 'statistics', 'nobel'],
             $bkm[17]['tags']
         );
         $this->assertEquals(
@@ -450,14 +452,14 @@ class ParseFirefoxBookmarksTest extends \PHPUnit_Framework_TestCase
         );
         $this->assertEquals(
             'Chocolate Consumption, Cognitive Function, and Nobel Laureates'
-           .' - Chocolate consumption cognitive function and nobel laurates'
-           .' (NEJM).pdf',
+            . ' - Chocolate consumption cognitive function and nobel laurates'
+            . ' (NEJM).pdf',
             $bkm[17]['title']
         );
         $this->assertEquals(
             'http://www.biostat.jhsph.edu/courses/bio621/misc/Chocolate%20'
-            .'consumption%20cognitive%20function%20and%20nobel'
-           .'%20laurates%20%28NEJM%29.pdf',
+            . 'consumption%20cognitive%20function%20and%20nobel'
+            . '%20laurates%20%28NEJM%29.pdf',
             $bkm[17]['uri']
         );
 
@@ -470,7 +472,7 @@ class ParseFirefoxBookmarksTest extends \PHPUnit_Framework_TestCase
             $bkm[18]['pub']
         );
         $this->assertEquals(
-            'statistics best-practices donot data analysis',
+            ['statistics', 'best-practices', 'donot', 'data', 'analysis'],
             $bkm[18]['tags']
         );
         $this->assertEquals(
@@ -495,7 +497,7 @@ class ParseFirefoxBookmarksTest extends \PHPUnit_Framework_TestCase
             $bkm[19]['pub']
         );
         $this->assertEquals(
-            'garfield markov language parody comic',
+            ['garfield', 'markov', 'language', 'parody', 'comic'],
             $bkm[19]['tags']
         );
         $this->assertEquals(
@@ -513,10 +515,10 @@ class ParseFirefoxBookmarksTest extends \PHPUnit_Framework_TestCase
 
         $this->assertEquals(
             'Opt out of global data surveillance programs like PRISM, XKeyscore'
-           .' and Tempora. Help make mass surveillance of entire populations'
-           .' uneconomical! We all have a right to privacy, which you can exercise'
-           .' today by encrypting your communications and ending your reliance'
-           .' on proprietary services.',
+            . ' and Tempora. Help make mass surveillance of entire populations'
+            . ' uneconomical! We all have a right to privacy, which you can exercise'
+            . ' today by encrypting your communications and ending your reliance'
+            . ' on proprietary services.',
             $bkm[20]['note']
         );
         $this->assertEquals(
@@ -524,7 +526,7 @@ class ParseFirefoxBookmarksTest extends \PHPUnit_Framework_TestCase
             $bkm[20]['pub']
         );
         $this->assertEquals(
-            'prism break privacy self-hosted web service',
+            ['prism', 'break', 'privacy', 'self-hosted', 'web', 'service'],
             $bkm[20]['tags']
         );
         $this->assertEquals(
@@ -533,7 +535,7 @@ class ParseFirefoxBookmarksTest extends \PHPUnit_Framework_TestCase
         );
         $this->assertEquals(
             'Opt out of global data surveillance programs like PRISM, XKeyscore,'
-           .' and Tempora - PRISM Break - PRISM Break',
+            . ' and Tempora - PRISM Break - PRISM Break',
             $bkm[20]['title']
         );
         $this->assertEquals(
@@ -543,7 +545,7 @@ class ParseFirefoxBookmarksTest extends \PHPUnit_Framework_TestCase
 
         $this->assertEquals(
             'Fractal Flowchart - Spiked Math Comic - A daily math webcomic'
-            .' meant to entertain and humor the geek in you...',
+            . ' meant to entertain and humor the geek in you...',
             $bkm[21]['note']
         );
         $this->assertEquals(
@@ -551,7 +553,7 @@ class ParseFirefoxBookmarksTest extends \PHPUnit_Framework_TestCase
             $bkm[21]['pub']
         );
         $this->assertEquals(
-            'math fractal flowchart chart',
+            ['math', 'fractal', 'flowchart', 'chart'],
             $bkm[21]['tags']
         );
         $this->assertEquals(
@@ -569,7 +571,7 @@ class ParseFirefoxBookmarksTest extends \PHPUnit_Framework_TestCase
 
         $this->assertEquals('', $bkm[23]['note']);
         $this->assertEquals('1', $bkm[23]['pub']);
-        $this->assertEquals('', $bkm[23]['tags']);
+        $this->assertEquals([], $bkm[23]['tags']);
         $this->assertEquals(
             '1460294956',
             $bkm[22]['time']
@@ -585,7 +587,7 @@ class ParseFirefoxBookmarksTest extends \PHPUnit_Framework_TestCase
 
         $this->assertEquals('', $bkm[23]['note']);
         $this->assertEquals('1', $bkm[23]['pub']);
-        $this->assertEquals('', $bkm[23]['tags']);
+        $this->assertEquals([], $bkm[23]['tags']);
         $this->assertEquals(
             '1460294956',
             $bkm[23]['time']
@@ -611,7 +613,7 @@ class ParseFirefoxBookmarksTest extends \PHPUnit_Framework_TestCase
 
         $this->assertEquals('', $bkm[0]['note']);
         $this->assertEquals('1', $bkm[0]['pub']);
-        $this->assertEquals('', $bkm[0]['tags']);
+        $this->assertEquals([], $bkm[0]['tags']);
         $this->assertEquals(
             '1460294956',
             $bkm[0]['time']
@@ -622,13 +624,13 @@ class ParseFirefoxBookmarksTest extends \PHPUnit_Framework_TestCase
         );
         $this->assertEquals(
             'place:folder=BOOKMARKS_MENU&folder=UNFILED_BOOKMARKS&folder=TOOLBAR'
-           .'&queryType=1&sort=12&maxResults=10&excludeQueries=1',
+            . '&queryType=1&sort=12&maxResults=10&excludeQueries=1',
             $bkm[0]['uri']
         );
 
         $this->assertEquals('', $bkm[0]['note']);
         $this->assertEquals('1', $bkm[0]['pub']);
-        $this->assertEquals('', $bkm[0]['tags']);
+        $this->assertEquals([], $bkm[0]['tags']);
         $this->assertEquals(
             '1460294956',
             $bkm[1]['time']
@@ -651,7 +653,7 @@ class ParseFirefoxBookmarksTest extends \PHPUnit_Framework_TestCase
             $bkm[2]['pub']
         );
         $this->assertEquals(
-            'tolkien lord rings elves timeline graphics genealogy fantasy',
+            ['tolkien','lord','rings','elves','timeline','graphics','genealogy','fantasy'],
             $bkm[2]['tags']
         );
         $this->assertEquals(
@@ -676,7 +678,7 @@ class ParseFirefoxBookmarksTest extends \PHPUnit_Framework_TestCase
             $bkm[3]['pub']
         );
         $this->assertEquals(
-            'comics webcomic commit code review dev',
+            ['comics','webcomic','commit','code','review','dev'],
             $bkm[3]['tags']
         );
         $this->assertEquals(
@@ -701,7 +703,7 @@ class ParseFirefoxBookmarksTest extends \PHPUnit_Framework_TestCase
             $bkm[4]['pub']
         );
         $this->assertEquals(
-            'comics xkcd webcomic slope respect',
+            ['comics','xkcd','webcomic','slope','respect'],
             $bkm[4]['tags']
         );
         $this->assertEquals(
@@ -726,7 +728,7 @@ class ParseFirefoxBookmarksTest extends \PHPUnit_Framework_TestCase
             $bkm[5]['pub']
         );
         $this->assertEquals(
-            'comics garfield markov language parody comic',
+            ['comics','garfield','markov','language','parody','comic'],
             $bkm[5]['tags']
         );
         $this->assertEquals(
@@ -744,7 +746,7 @@ class ParseFirefoxBookmarksTest extends \PHPUnit_Framework_TestCase
 
         $this->assertEquals(
             'Fractal Flowchart - Spiked Math Comic - A daily math webcomic'
-            .' meant to entertain and humor the geek in you...',
+            . ' meant to entertain and humor the geek in you...',
             $bkm[6]['note']
         );
         $this->assertEquals(
@@ -752,7 +754,7 @@ class ParseFirefoxBookmarksTest extends \PHPUnit_Framework_TestCase
             $bkm[6]['pub']
         );
         $this->assertEquals(
-            'comics math fractal flowchart chart',
+            ['comics','math','fractal','flowchart','chart'],
             $bkm[6]['tags']
         );
         $this->assertEquals(
@@ -771,7 +773,7 @@ class ParseFirefoxBookmarksTest extends \PHPUnit_Framework_TestCase
         $this->assertEquals('', $bkm[7]['note']);
         $this->assertEquals('1', $bkm[7]['pub']);
         $this->assertEquals(
-            'dev lua script cpp dev',
+            ['dev','lua','script','cpp','dev'],
             $bkm[7]['tags']
         );
         $this->assertEquals(
@@ -789,7 +791,7 @@ class ParseFirefoxBookmarksTest extends \PHPUnit_Framework_TestCase
 
         $this->assertEquals(
             'Let’s play a game. I’ll show you a picture and a couple videos'
-           .'—just watch the first five seconds or so—and you figure out&amp;#8230;',
+            . '—just watch the first five seconds or so—and you figure out&amp;#8230;',
             $bkm[8]['note']
         );
         $this->assertEquals(
@@ -797,7 +799,7 @@ class ParseFirefoxBookmarksTest extends \PHPUnit_Framework_TestCase
             $bkm[8]['pub']
         );
         $this->assertEquals(
-            'dev teapot 418 computer graphics image sythesis',
+            ['dev','teapot','418','computer','graphics','image','sythesis'],
             $bkm[8]['tags']
         );
         $this->assertEquals(
@@ -806,12 +808,12 @@ class ParseFirefoxBookmarksTest extends \PHPUnit_Framework_TestCase
         );
         $this->assertEquals(
             'The Most Important Object In Computer Graphics History Is This Teapot'
-           .' - Facts So Romantic - Nautilus',
+            . ' - Facts So Romantic - Nautilus',
             $bkm[8]['title']
         );
         $this->assertEquals(
             'http://nautil.us/blog/the-most-important-object-in-computer-graphics'
-           .'-history-is-this-teapot',
+            . '-history-is-this-teapot',
             $bkm[8]['uri']
         );
 
@@ -824,7 +826,7 @@ class ParseFirefoxBookmarksTest extends \PHPUnit_Framework_TestCase
             $bkm[9]['pub']
         );
         $this->assertEquals(
-            'dev hg mercurial version control scm python tutorial',
+            ['dev', 'hg', 'mercurial', 'version', 'control', 'scm', 'python', 'tutorial'],
             $bkm[9]['tags']
         );
         $this->assertEquals(
@@ -849,7 +851,7 @@ class ParseFirefoxBookmarksTest extends \PHPUnit_Framework_TestCase
             $bkm[10]['pub']
         );
         $this->assertEquals(
-            'dev emacs editor django pony python mode',
+            ['dev', 'emacs', 'editor', 'django', 'pony', 'python', 'mode'],
             $bkm[10]['tags']
         );
         $this->assertEquals(
@@ -862,7 +864,7 @@ class ParseFirefoxBookmarksTest extends \PHPUnit_Framework_TestCase
         );
         $this->assertEquals(
             'http://blog.deadpansincerity.com/2011/05/announcing-pony-mode-a-django'
-            .'-editing-mode-for-emacs/',
+            . '-editing-mode-for-emacs/',
             $bkm[10]['uri']
         );
 
@@ -875,7 +877,7 @@ class ParseFirefoxBookmarksTest extends \PHPUnit_Framework_TestCase
             $bkm[11]['pub']
         );
         $this->assertEquals(
-            'dev wikiwikiweb deadline rush',
+            ['dev', 'wikiwikiweb', 'deadline', 'rush'],
             $bkm[11]['tags']
         );
         $this->assertEquals(
@@ -900,7 +902,7 @@ class ParseFirefoxBookmarksTest extends \PHPUnit_Framework_TestCase
             $bkm[12]['pub']
         );
         $this->assertEquals(
-            'dev statistics best-practices donot data analysis',
+            ['dev', 'statistics', 'best-practices', 'donot', 'data', 'analysis'],
             $bkm[12]['tags']
         );
         $this->assertEquals(
@@ -918,7 +920,7 @@ class ParseFirefoxBookmarksTest extends \PHPUnit_Framework_TestCase
 
         $this->assertEquals(
             'netscape-bookmark-parser - a php script (function) to parse netscape'
-           .' format bookmark files',
+            . ' format bookmark files',
             $bkm[13]['note']
         );
         $this->assertEquals(
@@ -926,7 +928,7 @@ class ParseFirefoxBookmarksTest extends \PHPUnit_Framework_TestCase
             $bkm[13]['pub']
         );
         $this->assertEquals(
-            'dev php github netscape parser',
+            ['dev', 'php', 'github', 'netscape', 'parser'],
             $bkm[13]['tags']
         );
         $this->assertEquals(
@@ -935,7 +937,7 @@ class ParseFirefoxBookmarksTest extends \PHPUnit_Framework_TestCase
         );
         $this->assertEquals(
             'kafene/netscape-bookmark-parser: a php script (function) to parse'
-           .' netscape format bookmark files',
+            . ' netscape format bookmark files',
             $bkm[13]['title']
         );
         $this->assertEquals(
@@ -946,7 +948,7 @@ class ParseFirefoxBookmarksTest extends \PHPUnit_Framework_TestCase
         $this->assertEquals('', $bkm[14]['note']);
         $this->assertEquals('1', $bkm[14]['pub']);
         $this->assertEquals(
-            'dev php security best-practices web',
+            ['dev', 'php', 'security', 'best-practices', 'web'],
             $bkm[14]['tags']
         );
         $this->assertEquals(
@@ -955,7 +957,7 @@ class ParseFirefoxBookmarksTest extends \PHPUnit_Framework_TestCase
         );
         $this->assertEquals(
             'Survive The Deep End: PHP Security — Survive The Deep End:'
-           .' PHP Security :: v1.0a1',
+            . ' PHP Security :: v1.0a1',
             $bkm[14]['title']
         );
         $this->assertEquals(
@@ -972,7 +974,7 @@ class ParseFirefoxBookmarksTest extends \PHPUnit_Framework_TestCase
             $bkm[15]['pub']
         );
         $this->assertEquals(
-            'dev chocolate research wtf statistics nobel',
+            ['dev', 'chocolate', 'research', 'wtf', 'statistics', 'nobel'],
             $bkm[15]['tags']
         );
         $this->assertEquals(
@@ -981,21 +983,21 @@ class ParseFirefoxBookmarksTest extends \PHPUnit_Framework_TestCase
         );
         $this->assertEquals(
             'Chocolate Consumption, Cognitive Function, and Nobel Laureates'
-           .' - Chocolate consumption cognitive function and nobel laurates'
-           .' (NEJM).pdf',
+            . ' - Chocolate consumption cognitive function and nobel laurates'
+            . ' (NEJM).pdf',
             $bkm[15]['title']
         );
         $this->assertEquals(
             'http://www.biostat.jhsph.edu/courses/bio621/misc/Chocolate%20'
-            .'consumption%20cognitive%20function%20and%20nobel'
-           .'%20laurates%20%28NEJM%29.pdf',
+            . 'consumption%20cognitive%20function%20and%20nobel'
+            . '%20laurates%20%28NEJM%29.pdf',
             $bkm[15]['uri']
         );
 
         $this->assertEquals(
             'If running a Meetup feels like a full-time job, you&#39;re probably'
-           .' doing it wrong. Volunteering is important and you can make it work'
-           .' with some smart maneuvering.',
+            . ' doing it wrong. Volunteering is important and you can make it work'
+            . ' with some smart maneuvering.',
             $bkm[16]['note']
         );
         $this->assertEquals(
@@ -1003,7 +1005,7 @@ class ParseFirefoxBookmarksTest extends \PHPUnit_Framework_TestCase
             $bkm[16]['pub']
         );
         $this->assertEquals(
-            'floss meetup presentation event community',
+            ['floss', 'meetup', 'presentation', 'event', 'community'],
             $bkm[16]['tags']
         );
         $this->assertEquals(
@@ -1028,7 +1030,7 @@ class ParseFirefoxBookmarksTest extends \PHPUnit_Framework_TestCase
             $bkm[17]['pub']
         );
         $this->assertEquals(
-            'floss github windows compose character keyboard input',
+            ['floss', 'github', 'windows', 'compose', 'character', 'keyboard', 'input'],
             $bkm[17]['tags']
         );
         $this->assertEquals(
@@ -1053,7 +1055,7 @@ class ParseFirefoxBookmarksTest extends \PHPUnit_Framework_TestCase
             $bkm[18]['pub']
         );
         $this->assertEquals(
-            'floss sysadmin test unix linux network security',
+            ['floss', 'sysadmin', 'test', 'unix', 'linux', 'network', 'security'],
             $bkm[18]['tags']
         );
         $this->assertEquals(
@@ -1078,7 +1080,7 @@ class ParseFirefoxBookmarksTest extends \PHPUnit_Framework_TestCase
             $bkm[19]['pub']
         );
         $this->assertEquals(
-            'floss question faq bug report dev support',
+            ['floss', 'question', 'faq', 'bug', 'report', 'dev', 'support'],
             $bkm[19]['tags']
         );
         $this->assertEquals(
@@ -1096,10 +1098,10 @@ class ParseFirefoxBookmarksTest extends \PHPUnit_Framework_TestCase
 
         $this->assertEquals(
             'Opt out of global data surveillance programs like PRISM, XKeyscore'
-           .' and Tempora. Help make mass surveillance of entire populations'
-           .' uneconomical! We all have a right to privacy, which you can exercise'
-           .' today by encrypting your communications and ending your reliance'
-           .' on proprietary services.',
+            . ' and Tempora. Help make mass surveillance of entire populations'
+            . ' uneconomical! We all have a right to privacy, which you can exercise'
+            . ' today by encrypting your communications and ending your reliance'
+            . ' on proprietary services.',
             $bkm[20]['note']
         );
         $this->assertEquals(
@@ -1107,7 +1109,7 @@ class ParseFirefoxBookmarksTest extends \PHPUnit_Framework_TestCase
             $bkm[20]['pub']
         );
         $this->assertEquals(
-            'floss prism break privacy self-hosted web service',
+            ['floss', 'prism', 'break', 'privacy', 'self-hosted', 'web', 'service'],
             $bkm[20]['tags']
         );
         $this->assertEquals(
@@ -1116,7 +1118,7 @@ class ParseFirefoxBookmarksTest extends \PHPUnit_Framework_TestCase
         );
         $this->assertEquals(
             'Opt out of global data surveillance programs like PRISM, XKeyscore,'
-           .' and Tempora - PRISM Break - PRISM Break',
+            . ' and Tempora - PRISM Break - PRISM Break',
             $bkm[20]['title']
         );
         $this->assertEquals(
@@ -1133,7 +1135,7 @@ class ParseFirefoxBookmarksTest extends \PHPUnit_Framework_TestCase
             $bkm[21]['pub']
         );
         $this->assertEquals(
-            'games minecraft game indie pig wtf',
+            ['games', 'minecraft', 'game', 'indie', 'pig', 'wtf'],
             $bkm[21]['tags']
         );
         $this->assertEquals(
@@ -1146,14 +1148,14 @@ class ParseFirefoxBookmarksTest extends \PHPUnit_Framework_TestCase
         );
         $this->assertEquals(
             'http://gaming.stackexchange.com/questions/21261/is-it-dangerous-to-go-extreme'
-           .'-pig-riding-in-a-thunderstorm',
+            . '-pig-riding-in-a-thunderstorm',
             $bkm[21]['uri']
         );
 
         $this->assertEquals('', $bkm[22]['note']);
         $this->assertEquals('1', $bkm[22]['pub']);
         $this->assertEquals(
-            'personal toolbar',
+            ['personal', 'toolbar'],
             $bkm[22]['tags']
         );
         $this->assertEquals(
@@ -1172,7 +1174,7 @@ class ParseFirefoxBookmarksTest extends \PHPUnit_Framework_TestCase
         $this->assertEquals('', $bkm[23]['note']);
         $this->assertEquals('1', $bkm[23]['pub']);
         $this->assertEquals(
-            'personal toolbar',
+            ['personal', 'toolbar'],
             $bkm[23]['tags']
         );
         $this->assertEquals(
