@@ -1,5 +1,7 @@
 <?php
 
+declare(strict_types=1);
+
 namespace Shaarli\NetscapeBookmarkParser;
 
 /**
@@ -7,22 +9,22 @@ namespace Shaarli\NetscapeBookmarkParser;
  *
  * The reference data has been dumped with IE 11
  */
-class ParseInternetExplorerBookmarksTest extends \PHPUnit_Framework_TestCase
+class ParseInternetExplorerBookmarksTest extends TestCase
 {
     protected $parser = null;
 
     /**
      * Initialize test resources
      */
-    public function setUp()
+    protected function setUp(): void
     {
-        $this->parser = new NetscapeBookmarkParser(true, array(), 'error');
+        $this->parser = new NetscapeBookmarkParser(true, [], 'error');
     }
 
     /**
      * Delete log file.
      */
-    public function tearDown()
+    protected function tearDown(): void
     {
         @unlink(LoggerTestsUtils::getLogFile());
     }
@@ -39,7 +41,7 @@ class ParseInternetExplorerBookmarksTest extends \PHPUnit_Framework_TestCase
 
         $this->assertEquals('', $bkm[0]['note']);
         $this->assertEquals('1', $bkm[0]['pub']);
-        $this->assertEquals('', $bkm[0]['tags']);
+        $this->assertEquals([], $bkm[0]['tags']);
         $this->assertEquals('1466267453', $bkm[0]['time']);
         $this->assertEquals(
             'A better git log (Example)  Coderwall',
@@ -52,7 +54,7 @@ class ParseInternetExplorerBookmarksTest extends \PHPUnit_Framework_TestCase
 
         $this->assertEquals('', $bkm[1]['note']);
         $this->assertEquals('1', $bkm[1]['pub']);
-        $this->assertEquals('', $bkm[1]['tags']);
+        $this->assertEquals([], $bkm[1]['tags']);
         $this->assertEquals('1466271589', $bkm[1]['time']);
         $this->assertEquals(
             'Authentication Cheat Sheet - OWASP',
@@ -65,7 +67,7 @@ class ParseInternetExplorerBookmarksTest extends \PHPUnit_Framework_TestCase
 
         $this->assertEquals('', $bkm[2]['note']);
         $this->assertEquals('1', $bkm[2]['pub']);
-        $this->assertEquals('', $bkm[2]['tags']);
+        $this->assertEquals([], $bkm[2]['tags']);
         $this->assertEquals('1466270244', $bkm[2]['time']);
         $this->assertEquals('CSS 3D Clouds', $bkm[2]['title']);
         $this->assertEquals(
@@ -75,7 +77,7 @@ class ParseInternetExplorerBookmarksTest extends \PHPUnit_Framework_TestCase
 
         $this->assertEquals('', $bkm[3]['note']);
         $this->assertEquals('1', $bkm[3]['pub']);
-        $this->assertEquals('', $bkm[3]['tags']);
+        $this->assertEquals([], $bkm[3]['tags']);
         $this->assertEquals('1466269537', $bkm[3]['time']);
         $this->assertEquals(
             'Dealing with line endings - User Documentation',
@@ -83,13 +85,13 @@ class ParseInternetExplorerBookmarksTest extends \PHPUnit_Framework_TestCase
         );
         $this->assertEquals(
             'https://help.github.com/articles/dealing-with-line-endings/'
-           .'#platform-all',
+            . '#platform-all',
             $bkm[3]['uri']
         );
 
         $this->assertEquals('', $bkm[4]['note']);
         $this->assertEquals('1', $bkm[4]['pub']);
-        $this->assertEquals('', $bkm[4]['tags']);
+        $this->assertEquals([], $bkm[4]['tags']);
         $this->assertEquals('1466267067', $bkm[4]['time']);
         $this->assertEquals(
             'Documentation of Album Covers Recreated with MS Paint',
@@ -102,30 +104,30 @@ class ParseInternetExplorerBookmarksTest extends \PHPUnit_Framework_TestCase
 
         $this->assertEquals('', $bkm[5]['note']);
         $this->assertEquals('1', $bkm[5]['pub']);
-        $this->assertEquals('', $bkm[5]['tags']);
+        $this->assertEquals([], $bkm[5]['tags']);
         $this->assertEquals('1466267083', $bkm[5]['time']);
         $this->assertEquals('Excuses For Lazy Coders', $bkm[5]['title']);
         $this->assertEquals('http://developerexcuses.com/', $bkm[5]['uri']);
 
         $this->assertEquals('', $bkm[6]['note']);
         $this->assertEquals('1', $bkm[6]['pub']);
-        $this->assertEquals('', $bkm[6]['tags']);
+        $this->assertEquals([], $bkm[6]['tags']);
         $this->assertEquals('1466266989', $bkm[6]['time']);
         $this->assertEquals(
             'Fifty Shades of Grey text generator  '
-           .'Parody erotic fiction generated algorithmically.',
+            . 'Parody erotic fiction generated algorithmically.',
             $bkm[6]['title']
         );
         $this->assertEquals('http://www.xwray.com/fiftyshades', $bkm[6]['uri']);
 
         $this->assertEquals('', $bkm[7]['note']);
         $this->assertEquals('1', $bkm[7]['pub']);
-        $this->assertEquals('', $bkm[7]['tags']);
+        $this->assertEquals([], $bkm[7]['tags']);
         $this->assertEquals('1466267009', $bkm[7]['time']);
         $this->assertEquals(
             'GitHub - originell-django-kittenstorage '
-           .'Django Storage Engine which returns images of kittens '
-           .'if files could not be found.',
+            . 'Django Storage Engine which returns images of kittens '
+            . 'if files could not be found.',
             $bkm[7]['title']
         );
         $this->assertEquals(
@@ -135,7 +137,7 @@ class ParseInternetExplorerBookmarksTest extends \PHPUnit_Framework_TestCase
 
         $this->assertEquals('', $bkm[8]['note']);
         $this->assertEquals('1', $bkm[8]['pub']);
-        $this->assertEquals('', $bkm[8]['tags']);
+        $this->assertEquals([], $bkm[8]['tags']);
         $this->assertEquals('1466266984', $bkm[8]['time']);
         $this->assertEquals('Heroic Programming', $bkm[8]['title']);
         $this->assertEquals(
@@ -145,7 +147,7 @@ class ParseInternetExplorerBookmarksTest extends \PHPUnit_Framework_TestCase
 
         $this->assertEquals('', $bkm[9]['note']);
         $this->assertEquals('1', $bkm[9]['pub']);
-        $this->assertEquals('', $bkm[9]['tags']);
+        $this->assertEquals([], $bkm[9]['tags']);
         $this->assertEquals('1466271584', $bkm[9]['time']);
         $this->assertEquals(
             'Hg Init a Mercurial tutorial by Joel Spolsky',
@@ -155,7 +157,7 @@ class ParseInternetExplorerBookmarksTest extends \PHPUnit_Framework_TestCase
 
         $this->assertEquals('', $bkm[10]['note']);
         $this->assertEquals('1', $bkm[10]['pub']);
-        $this->assertEquals('', $bkm[10]['tags']);
+        $this->assertEquals([], $bkm[10]['tags']);
         $this->assertEquals('1466267047', $bkm[10]['time']);
         $this->assertEquals(
             'http--www.brendangregg.com-Specials-mkzombie.c',
@@ -168,18 +170,18 @@ class ParseInternetExplorerBookmarksTest extends \PHPUnit_Framework_TestCase
 
         $this->assertEquals('', $bkm[11]['note']);
         $this->assertEquals('1', $bkm[11]['pub']);
-        $this->assertEquals('', $bkm[11]['tags']);
+        $this->assertEquals([], $bkm[11]['tags']);
         $this->assertEquals('1466271425', $bkm[11]['time']);
         $this->assertEquals('It Never works with cats...', $bkm[11]['title']);
         $this->assertEquals(
             'http://lizclimo.tumblr.com/post/132165201759/'
-           .'bonus-comic-for-national-cat-day',
+            . 'bonus-comic-for-national-cat-day',
             $bkm[11]['uri']
         );
 
         $this->assertEquals('', $bkm[12]['note']);
         $this->assertEquals('1', $bkm[12]['pub']);
-        $this->assertEquals('', $bkm[12]['tags']);
+        $this->assertEquals([], $bkm[12]['tags']);
         $this->assertEquals('1466269580', $bkm[12]['time']);
         $this->assertEquals(
             'Learn to write Gallifreyan in 9 simple steps',
@@ -187,31 +189,31 @@ class ParseInternetExplorerBookmarksTest extends \PHPUnit_Framework_TestCase
         );
         $this->assertEquals(
             'http://io9.gizmodo.com/learn-to-write-gallifreyan-in-9'
-           .'-simple-steps-506989915',
+            . '-simple-steps-506989915',
             $bkm[12]['uri']
         );
 
         $this->assertEquals('', $bkm[13]['note']);
         $this->assertEquals('1', $bkm[13]['pub']);
-        $this->assertEquals('', $bkm[13]['tags']);
+        $this->assertEquals([], $bkm[13]['tags']);
         $this->assertEquals('1466271385', $bkm[13]['time']);
         $this->assertEquals('Let me google that for you', $bkm[13]['title']);
         $this->assertEquals('http://lmgtfy.com/', $bkm[13]['uri']);
 
         $this->assertEquals('', $bkm[14]['note']);
         $this->assertEquals('1', $bkm[14]['pub']);
-        $this->assertEquals('', $bkm[14]['tags']);
+        $this->assertEquals([], $bkm[14]['tags']);
         $this->assertEquals('1466269615', $bkm[14]['time']);
         $this->assertEquals('PHP Sadness', $bkm[14]['title']);
         $this->assertEquals('http://phpsadness.com/', $bkm[14]['uri']);
 
         $this->assertEquals('', $bkm[15]['note']);
         $this->assertEquals('1', $bkm[15]['pub']);
-        $this->assertEquals('', $bkm[15]['tags']);
+        $this->assertEquals([], $bkm[15]['tags']);
         $this->assertEquals('1466269520', $bkm[15]['time']);
         $this->assertEquals(
             'TEDxZurich - Jojo Mayer - Exploring the distance between 0 and 1'
-           .' - YouTube',
+            . ' - YouTube',
             $bkm[15]['title']
         );
         $this->assertEquals(
@@ -221,7 +223,7 @@ class ParseInternetExplorerBookmarksTest extends \PHPUnit_Framework_TestCase
 
         $this->assertEquals('', $bkm[16]['note']);
         $this->assertEquals('1', $bkm[16]['pub']);
-        $this->assertEquals('', $bkm[16]['tags']);
+        $this->assertEquals([], $bkm[16]['tags']);
         $this->assertEquals('1466267119', $bkm[16]['time']);
         $this->assertEquals('UserFriendly - Web Designer', $bkm[16]['title']);
         $this->assertEquals(
@@ -231,7 +233,7 @@ class ParseInternetExplorerBookmarksTest extends \PHPUnit_Framework_TestCase
 
         $this->assertEquals('', $bkm[17]['note']);
         $this->assertEquals('1', $bkm[17]['pub']);
-        $this->assertEquals('', $bkm[17]['tags']);
+        $this->assertEquals([], $bkm[17]['tags']);
         $this->assertEquals('1466271475', $bkm[17]['time']);
         $this->assertEquals(
             'XKCD Plots in Matplotlib Going the Whole Way',
@@ -239,7 +241,7 @@ class ParseInternetExplorerBookmarksTest extends \PHPUnit_Framework_TestCase
         );
         $this->assertEquals(
             'http://jakevdp.github.io/blog/2013/07/10/'
-           .'XKCD-plots-in-matplotlib/',
+            . 'XKCD-plots-in-matplotlib/',
             $bkm[17]['uri']
         );
     }
@@ -257,7 +259,7 @@ class ParseInternetExplorerBookmarksTest extends \PHPUnit_Framework_TestCase
 
         $this->assertEquals('', $bkm[0]['note']);
         $this->assertEquals('1', $bkm[0]['pub']);
-        $this->assertEquals('comics', $bkm[0]['tags']);
+        $this->assertEquals(['comics'], $bkm[0]['tags']);
         $this->assertEquals('1466271425', $bkm[0]['time']);
         $this->assertEquals(
             'It Never works with cats...',
@@ -265,13 +267,13 @@ class ParseInternetExplorerBookmarksTest extends \PHPUnit_Framework_TestCase
         );
         $this->assertEquals(
             'http://lizclimo.tumblr.com/post/132165201759/'
-           .'bonus-comic-for-national-cat-day',
+            . 'bonus-comic-for-national-cat-day',
             $bkm[0]['uri']
         );
 
         $this->assertEquals('', $bkm[1]['note']);
         $this->assertEquals('1', $bkm[1]['pub']);
-        $this->assertEquals('comics', $bkm[1]['tags']);
+        $this->assertEquals(['comics'], $bkm[1]['tags']);
         $this->assertEquals('1466267119', $bkm[1]['time']);
         $this->assertEquals(
             'UserFriendly - Web Designer',
@@ -284,7 +286,7 @@ class ParseInternetExplorerBookmarksTest extends \PHPUnit_Framework_TestCase
 
         $this->assertEquals('', $bkm[2]['note']);
         $this->assertEquals('1', $bkm[2]['pub']);
-        $this->assertEquals('dev php', $bkm[2]['tags']);
+        $this->assertEquals(['dev', 'php'], $bkm[2]['tags']);
         $this->assertEquals('1466269615', $bkm[2]['time']);
         $this->assertEquals(
             'PHP Sadness',
@@ -297,12 +299,12 @@ class ParseInternetExplorerBookmarksTest extends \PHPUnit_Framework_TestCase
 
         $this->assertEquals('', $bkm[3]['note']);
         $this->assertEquals('1', $bkm[3]['pub']);
-        $this->assertEquals('dev python', $bkm[3]['tags']);
+        $this->assertEquals(['dev', 'python'], $bkm[3]['tags']);
         $this->assertEquals('1466267009', $bkm[3]['time']);
         $this->assertEquals(
             'GitHub - originell-django-kittenstorage'
-           .' Django Storage Engine which returns images of kittens'
-           .' if files could not be found.',
+            . ' Django Storage Engine which returns images of kittens'
+            . ' if files could not be found.',
             $bkm[3]['title']
         );
         $this->assertEquals(
@@ -312,7 +314,7 @@ class ParseInternetExplorerBookmarksTest extends \PHPUnit_Framework_TestCase
 
         $this->assertEquals('', $bkm[4]['note']);
         $this->assertEquals('1', $bkm[4]['pub']);
-        $this->assertEquals('dev python', $bkm[4]['tags']);
+        $this->assertEquals(['dev', 'python'], $bkm[4]['tags']);
         $this->assertEquals('1466271475', $bkm[4]['time']);
         $this->assertEquals(
             'XKCD Plots in Matplotlib Going the Whole Way',
@@ -320,13 +322,13 @@ class ParseInternetExplorerBookmarksTest extends \PHPUnit_Framework_TestCase
         );
         $this->assertEquals(
             'http://jakevdp.github.io/blog/2013/07/10/'
-           .'XKCD-plots-in-matplotlib/',
+            . 'XKCD-plots-in-matplotlib/',
             $bkm[4]['uri']
         );
 
         $this->assertEquals('', $bkm[5]['note']);
         $this->assertEquals('1', $bkm[5]['pub']);
-        $this->assertEquals('dev scm', $bkm[5]['tags']);
+        $this->assertEquals(['dev', 'scm'], $bkm[5]['tags']);
         $this->assertEquals('1466267453', $bkm[5]['time']);
         $this->assertEquals(
             'A better git log (Example)  Coderwall',
@@ -339,7 +341,7 @@ class ParseInternetExplorerBookmarksTest extends \PHPUnit_Framework_TestCase
 
         $this->assertEquals('', $bkm[6]['note']);
         $this->assertEquals('1', $bkm[6]['pub']);
-        $this->assertEquals('dev scm', $bkm[6]['tags']);
+        $this->assertEquals(['dev', 'scm'], $bkm[6]['tags']);
         $this->assertEquals('1466269537', $bkm[6]['time']);
         $this->assertEquals(
             'Dealing with line endings - User Documentation',
@@ -347,13 +349,13 @@ class ParseInternetExplorerBookmarksTest extends \PHPUnit_Framework_TestCase
         );
         $this->assertEquals(
             'https://help.github.com/articles/dealing-with-line-endings/'
-           .'#platform-all',
+            . '#platform-all',
             $bkm[6]['uri']
         );
 
         $this->assertEquals('', $bkm[7]['note']);
         $this->assertEquals('1', $bkm[7]['pub']);
-        $this->assertEquals('dev scm', $bkm[7]['tags']);
+        $this->assertEquals(['dev', 'scm'], $bkm[7]['tags']);
         $this->assertEquals('1466271584', $bkm[7]['time']);
         $this->assertEquals(
             'Hg Init a Mercurial tutorial by Joel Spolsky',
@@ -366,7 +368,7 @@ class ParseInternetExplorerBookmarksTest extends \PHPUnit_Framework_TestCase
 
         $this->assertEquals('', $bkm[8]['note']);
         $this->assertEquals('1', $bkm[8]['pub']);
-        $this->assertEquals('dev', $bkm[8]['tags']);
+        $this->assertEquals(['dev'], $bkm[8]['tags']);
         $this->assertEquals('1466271589', $bkm[8]['time']);
         $this->assertEquals(
             'Authentication Cheat Sheet - OWASP',
@@ -379,7 +381,7 @@ class ParseInternetExplorerBookmarksTest extends \PHPUnit_Framework_TestCase
 
         $this->assertEquals('', $bkm[9]['note']);
         $this->assertEquals('1', $bkm[9]['pub']);
-        $this->assertEquals('dev', $bkm[9]['tags']);
+        $this->assertEquals(['dev'], $bkm[9]['tags']);
         $this->assertEquals('1466270244', $bkm[9]['time']);
         $this->assertEquals(
             'CSS 3D Clouds',
@@ -392,7 +394,7 @@ class ParseInternetExplorerBookmarksTest extends \PHPUnit_Framework_TestCase
 
         $this->assertEquals('', $bkm[10]['note']);
         $this->assertEquals('1', $bkm[10]['pub']);
-        $this->assertEquals('dev', $bkm[10]['tags']);
+        $this->assertEquals(['dev'], $bkm[10]['tags']);
         $this->assertEquals('1466267083', $bkm[10]['time']);
         $this->assertEquals(
             'Excuses For Lazy Coders',
@@ -405,11 +407,11 @@ class ParseInternetExplorerBookmarksTest extends \PHPUnit_Framework_TestCase
 
         $this->assertEquals('', $bkm[11]['note']);
         $this->assertEquals('1', $bkm[11]['pub']);
-        $this->assertEquals('dev', $bkm[11]['tags']);
+        $this->assertEquals(['dev'], $bkm[11]['tags']);
         $this->assertEquals('1466266989', $bkm[11]['time']);
         $this->assertEquals(
             'Fifty Shades of Grey text generator'
-           .'  Parody erotic fiction generated algorithmically.',
+            . '  Parody erotic fiction generated algorithmically.',
             $bkm[11]['title']
         );
         $this->assertEquals(
@@ -419,7 +421,7 @@ class ParseInternetExplorerBookmarksTest extends \PHPUnit_Framework_TestCase
 
         $this->assertEquals('', $bkm[12]['note']);
         $this->assertEquals('1', $bkm[12]['pub']);
-        $this->assertEquals('dev', $bkm[12]['tags']);
+        $this->assertEquals(['dev'], $bkm[12]['tags']);
         $this->assertEquals('1466266984', $bkm[12]['time']);
         $this->assertEquals(
             'Heroic Programming',
@@ -432,7 +434,7 @@ class ParseInternetExplorerBookmarksTest extends \PHPUnit_Framework_TestCase
 
         $this->assertEquals('', $bkm[13]['note']);
         $this->assertEquals('1', $bkm[13]['pub']);
-        $this->assertEquals('dev', $bkm[13]['tags']);
+        $this->assertEquals(['dev'], $bkm[13]['tags']);
         $this->assertEquals('1466267047', $bkm[13]['time']);
         $this->assertEquals(
             'http--www.brendangregg.com-Specials-mkzombie.c',
@@ -445,7 +447,7 @@ class ParseInternetExplorerBookmarksTest extends \PHPUnit_Framework_TestCase
 
         $this->assertEquals('', $bkm[14]['note']);
         $this->assertEquals('1', $bkm[14]['pub']);
-        $this->assertEquals('microsoft websites', $bkm[14]['tags']);
+        $this->assertEquals(['microsoft', 'websites'], $bkm[14]['tags']);
         $this->assertEquals('1363037966', $bkm[14]['time']);
         $this->assertEquals(
             'IE Add-on site',
@@ -458,7 +460,7 @@ class ParseInternetExplorerBookmarksTest extends \PHPUnit_Framework_TestCase
 
         $this->assertEquals('', $bkm[15]['note']);
         $this->assertEquals('1', $bkm[15]['pub']);
-        $this->assertEquals('microsoft websites', $bkm[15]['tags']);
+        $this->assertEquals(['microsoft', 'websites'], $bkm[15]['tags']);
         $this->assertEquals('1363037966', $bkm[15]['time']);
         $this->assertEquals(
             'IE site on Microsoft.com',
@@ -471,7 +473,7 @@ class ParseInternetExplorerBookmarksTest extends \PHPUnit_Framework_TestCase
 
         $this->assertEquals('', $bkm[16]['note']);
         $this->assertEquals('1', $bkm[16]['pub']);
-        $this->assertEquals('microsoft websites', $bkm[16]['tags']);
+        $this->assertEquals(['microsoft', 'websites'], $bkm[16]['tags']);
         $this->assertEquals('1363037966', $bkm[16]['time']);
         $this->assertEquals(
             'Microsoft At Home',
@@ -484,7 +486,7 @@ class ParseInternetExplorerBookmarksTest extends \PHPUnit_Framework_TestCase
 
         $this->assertEquals('', $bkm[17]['note']);
         $this->assertEquals('1', $bkm[17]['pub']);
-        $this->assertEquals('microsoft websites', $bkm[17]['tags']);
+        $this->assertEquals(['microsoft', 'websites'], $bkm[17]['tags']);
         $this->assertEquals('1363037966', $bkm[17]['time']);
         $this->assertEquals(
             'Microsoft At Work',
@@ -497,7 +499,7 @@ class ParseInternetExplorerBookmarksTest extends \PHPUnit_Framework_TestCase
 
         $this->assertEquals('', $bkm[18]['note']);
         $this->assertEquals('1', $bkm[18]['pub']);
-        $this->assertEquals('microsoft websites', $bkm[18]['tags']);
+        $this->assertEquals(['microsoft', 'websites'], $bkm[18]['tags']);
         $this->assertEquals('1363037966', $bkm[18]['time']);
         $this->assertEquals(
             'Microsoft Store',
@@ -510,7 +512,7 @@ class ParseInternetExplorerBookmarksTest extends \PHPUnit_Framework_TestCase
 
         $this->assertEquals('', $bkm[19]['note']);
         $this->assertEquals('1', $bkm[19]['pub']);
-        $this->assertEquals('music', $bkm[19]['tags']);
+        $this->assertEquals(['music'], $bkm[19]['tags']);
         $this->assertEquals('1466267067', $bkm[19]['time']);
         $this->assertEquals(
             'Album Covers Recreated with MS Paint',
@@ -523,11 +525,11 @@ class ParseInternetExplorerBookmarksTest extends \PHPUnit_Framework_TestCase
 
         $this->assertEquals('', $bkm[20]['note']);
         $this->assertEquals('1', $bkm[20]['pub']);
-        $this->assertEquals('music', $bkm[20]['tags']);
+        $this->assertEquals(['music'], $bkm[20]['tags']);
         $this->assertEquals('1466269520', $bkm[20]['time']);
         $this->assertEquals(
             'TEDxZurich - Jojo Mayer - Exploring the distance between 0 and 1'
-           .' - YouTube',
+            . ' - YouTube',
             $bkm[20]['title']
         );
         $this->assertEquals(
@@ -537,7 +539,7 @@ class ParseInternetExplorerBookmarksTest extends \PHPUnit_Framework_TestCase
 
         $this->assertEquals('', $bkm[21]['note']);
         $this->assertEquals('1', $bkm[21]['pub']);
-        $this->assertEquals('windows live', $bkm[21]['tags']);
+        $this->assertEquals(['windows', 'live'], $bkm[21]['tags']);
         $this->assertEquals('1363037966', $bkm[21]['time']);
         $this->assertEquals(
             'Get Windows Live',
@@ -550,7 +552,7 @@ class ParseInternetExplorerBookmarksTest extends \PHPUnit_Framework_TestCase
 
         $this->assertEquals('', $bkm[22]['note']);
         $this->assertEquals('1', $bkm[22]['pub']);
-        $this->assertEquals('windows live', $bkm[22]['tags']);
+        $this->assertEquals(['windows', 'live'], $bkm[22]['tags']);
         $this->assertEquals('1363037966', $bkm[22]['time']);
         $this->assertEquals(
             'Windows Live Gallery',
@@ -563,7 +565,7 @@ class ParseInternetExplorerBookmarksTest extends \PHPUnit_Framework_TestCase
 
         $this->assertEquals('', $bkm[23]['note']);
         $this->assertEquals('1', $bkm[23]['pub']);
-        $this->assertEquals('windows live', $bkm[23]['tags']);
+        $this->assertEquals(['windows', 'live'], $bkm[23]['tags']);
         $this->assertEquals('1363037966', $bkm[23]['time']);
         $this->assertEquals(
             'Windows Live Mail',
@@ -576,7 +578,7 @@ class ParseInternetExplorerBookmarksTest extends \PHPUnit_Framework_TestCase
 
         $this->assertEquals('', $bkm[24]['note']);
         $this->assertEquals('1', $bkm[24]['pub']);
-        $this->assertEquals('windows live', $bkm[24]['tags']);
+        $this->assertEquals(['windows', 'live'], $bkm[24]['tags']);
         $this->assertEquals('1363037966', $bkm[24]['time']);
         $this->assertEquals(
             'Windows Live Spaces',
@@ -589,7 +591,7 @@ class ParseInternetExplorerBookmarksTest extends \PHPUnit_Framework_TestCase
 
         $this->assertEquals('', $bkm[25]['note']);
         $this->assertEquals('1', $bkm[25]['pub']);
-        $this->assertEquals('', $bkm[25]['tags']);
+        $this->assertEquals([], $bkm[25]['tags']);
         $this->assertEquals('1466269580', $bkm[25]['time']);
         $this->assertEquals(
             'Learn to write Gallifreyan in 9 simple steps',
@@ -597,13 +599,13 @@ class ParseInternetExplorerBookmarksTest extends \PHPUnit_Framework_TestCase
         );
         $this->assertEquals(
             'http://io9.gizmodo.com/learn-to-write-gallifreyan-in-9'
-           .'-simple-steps-506989915',
+            . '-simple-steps-506989915',
             $bkm[25]['uri']
         );
 
         $this->assertEquals('', $bkm[26]['note']);
         $this->assertEquals('1', $bkm[26]['pub']);
-        $this->assertEquals('', $bkm[26]['tags']);
+        $this->assertEquals([], $bkm[26]['tags']);
         $this->assertEquals('1466271385', $bkm[26]['time']);
         $this->assertEquals(
             'Let me google that for you',
